Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
pyeditorjs/__init__.py | (no function) | 14 | 3 | 0 | 79%
pyeditorjs/blocks.py | _sanitize | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | block | 2 | 0 | 0 | 100%
pyeditorjs/blocks.py | block.wrapper | 2 | 0 | 0 | 100%
pyeditorjs/blocks.py | EditorJsBlock.id | 1 | 1 | 0 | 0%
pyeditorjs/blocks.py | EditorJsBlock.type | 1 | 1 | 0 | 0%
pyeditorjs/blocks.py | EditorJsBlock.data | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | EditorJsBlock.html | 1 | 1 | 0 | 0%
pyeditorjs/blocks.py | HeaderBlock.text | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | HeaderBlock.level | 4 | 1 | 0 | 75%
pyeditorjs/blocks.py | HeaderBlock.html | 4 | 0 | 0 | 100%
pyeditorjs/blocks.py | ParagraphBlock.text | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ParagraphBlock.html | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ListBlock.style | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ListBlock.items | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ListBlock.html | 6 | 1 | 0 | 83%
pyeditorjs/blocks.py | DelimiterBlock.html | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ImageBlock.file_url | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ImageBlock.caption | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ImageBlock.with_border | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ImageBlock.stretched | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ImageBlock.with_background | 1 | 0 | 0 | 100%
pyeditorjs/blocks.py | ImageBlock.html | 5 | 1 | 0 | 80%
pyeditorjs/blocks.py | QuoteBlock.html | 7 | 7 | 0 | 0%
pyeditorjs/blocks.py | TableBlock.html | 11 | 11 | 0 | 0%
pyeditorjs/blocks.py | CodeBlock.html | 4 | 4 | 0 | 0%
pyeditorjs/blocks.py | WarningBlock.html | 6 | 6 | 0 | 0%
pyeditorjs/blocks.py | RawBlock.html | 4 | 4 | 0 | 0%
pyeditorjs/blocks.py | (no function) | 75 | 0 | 0 | 100%
pyeditorjs/exceptions.py | (no function) | 4 | 0 | 0 | 100%
pyeditorjs/parser.py | EditorJsParser.__post_init__ | 2 | 1 | 0 | 50%
pyeditorjs/parser.py | EditorJsParser._get_block | 7 | 4 | 0 | 43%
pyeditorjs/parser.py | EditorJsParser.blocks | 8 | 1 | 0 | 88%
pyeditorjs/parser.py | EditorJsParser.__iter__ | 1 | 0 | 0 | 100%
pyeditorjs/parser.py | EditorJsParser.html | 1 | 0 | 0 | 100%
pyeditorjs/parser.py | (no function) | 15 | 0 | 0 | 100%
Total |  | 198 | 47 | 0 | 76%

No items found using the specified filter.